#
# spec file for package pantheon-tasks
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.tasks
Name:           pantheon-tasks
Version:        6.3.3
Release:        1.4
Summary:        Task Manager
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/tasks
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(champlain-0.12)
BuildRequires:  pkgconfig(clutter-1.0)
BuildRequires:  pkgconfig(evolution-data-server-1.2)
BuildRequires:  pkgconfig(geocode-glib-1.0)
BuildRequires:  pkgconfig(geocode-glib-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libedataserver-1.2)
BuildRequires:  pkgconfig(libgeoclue-2.0)
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libical)
BuildRequires:  pkgconfig(libportal)
BuildRequires:  pkgconfig(libportal-gtk3)
Provides:       elementary-tasks = %{version}
Obsoletes:      elementary-tasks < %{version}

%description
Synced tasks and reminders for the Pantheon Desktop.

%lang_package

%prep
%autosetup -n tasks-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Mon Nov  4 2024 Richard Rahl <rrahl0@opensuse.org>
- rename to pantheon-tasks
* Wed Aug 14 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 6.3.3:
  * Updated translations
- update to 6.3.2:
  * Fix a small color issue
  * Preparations for Gtk4
  * Application: use startup
  * Fixed Duplicated tasks in Scheduled
- update to 6.3.1:
  * New app icon
  * Updated translations
- update to 6.3.0:
  * Add offline support for newly created task lists in case its
    configured for the account
  * Automatically synchronize a task list whenever it is selected
    or the network becomes available again
- switch url to github, as we don't want to link to a different OS
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.2.0:
  * Send a notification when a task is due
* Fri Jan 21 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.1.0:
  * Drag and drop tasks between lists
  * Follow email and web links in the task description with
    Control + Click
  * Improved time zone handling
  * Performance improvements
  * Updated translations
* Thu Oct  7 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.0.4:
- Fixes:
  * Prevent account name headers from being displayed multiple
    times in the sidebar
  * Long descriptions are truncated at the end instead of the
    beginning
  * Removing descriptions is now saved
  * Placing the cursor in descriptions works consistently
- Improvements:
  * Replace the Delete shortcut key with Ctrl + Backspace
  * Add a confirmation dialog when deleting a task list
  * Improve performance in lists with lots of completed tasks
  * Updated translations
* Wed Sep  8 2021 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
